@@ -47,7 +47,7 @@ BEGIN {
 
     Exporter::export_ok_tags( qw( algo trust ) );
 
-    $VERSION = '0.16';
+    $VERSION = '0.18';
 }
 
 use constant DSA_ELGAMAL    => 1;
@@ -259,7 +259,7 @@ sub run_gnupg($) {
           or die "can't open $self->{output} for output: $!\n";
     } elsif ( $self->{output} ) {
       my $gpg = shift(@{$cmdline});
-      unshift(@{$cmdline}, '--output ' . $self->{output});
+      unshift(@{$cmdline}, '--output', $self->{output});
       unshift(@{$cmdline}, $gpg);
     } # Defaults to stdout
 
@@ -276,9 +276,9 @@ sub run_gnupg($) {
         POSIX::close( $f );
     }
 
-    print STDERR "GnuPG: executing `" . join(' ', @$cmdline) . "`" if $self->{trace};
+    print STDERR "GnuPG: executing `" . @{$cmdline} . "`" if 1 ||$self->{trace};
 
-    exec ( join(' ', @$cmdline) )
+    exec ( @$cmdline )
       or CORE::die "can't exec gnupg: $!\n";
     }
 }
@@ -361,7 +361,7 @@ sub new($%) {
     my $self = {};
     if ($args{homedir}) {
     croak ( "Invalid home directory: $args{homedir}\n")
-      unless -d $args{homedir} && -w _ && -x _;
+      unless -d $args{homedir} && -x _;
     $self->{homedir} = $args{homedir};
     }
     if ($args{options}) {
@@ -532,7 +532,14 @@ sub encrypt($%) {
     my $options = [];
     croak ( "no recipient specified\n" )
       unless $args{recipient} or $args{symmetric};
-    push @$options, "--recipient" => "'" . $args{recipient} . "'";
+
+    for my $recipient ( 
+            ref $args{recipient} eq 'ARRAY' 
+                ? @{ $args{recipient} } 
+                : $args{recipient}              ) {
+        $recipient =~ s/ /\ /g; # Escape spaces in the recipient. This fills some strange edge case
+        push @$options, "--recipient" => $recipient;
+    }
 
     push @$options, "--sign"        if $args{sign};
     croak ( "can't sign an symmetric encrypted message\n" )
@@ -1025,7 +1032,8 @@ parameter.
 If not using symmetric cryptography, you will have to provide this
 parameter. It should contains the userid of the intended recipient of
 the message. It will be used to look up the key to use to encrypt the
-message.
+message. The parameter can also take an array ref, if you want to encrypt
+the message for a group of recipients.
 
 =item sign
 
